# Version 1.0.1

- Added scripts to test the package
- Added scripts to build Docker container
- Updates to tests
- Added more example data files for different plate layouts
- Added documentation
- Added requirements files and updated manifest
- Added CHANGELOG.md